## dbt-snowflake 1.10.4 - December 10, 2025

### Under the Hood

- Update default python runtime version ([#1492](https://github.com/dbt-labs/dbt-adapters/issues/1492))

### Contributors
- [@jeremyyeo](https://github.com/jeremyyeo) ([#1492](https://github.com/dbt-labs/dbt-adapters/issues/1492))
